@@ -17,4 +17,7 @@ from . import applications
 from .applications import *
 from . import dataset
 from .dataset import *
-from .applications.trainer import Trainer
+from .applications.trainer import MultiGPUTrainer, CPUTrainer
+from . import utils
+from .utils import *
+
