@@ -58,7 +58,7 @@ def download_model(fleet_path, model_name):
                     'wget -P {} --no-check-certificate https://fleet.bj.bcebos.com/models/{}/{}.tar.gz'.
                     format(fleet_path, version, model_name))
             os.system('tar -xf {}{}.tar.gz -C {}'.format(
-                    fleet_path, model_name, fleet_path))
+                fleet_path, model_name, fleet_path))
     else:
         time.sleep(3)
 
@@ -165,7 +165,7 @@ class Transformer(ModelBase):
             shuffle=shuffle)
 
 
-class Bert_large(ModelBase):
+class BertLarge(ModelBase):
     def __init__(self):
         super(Bert_large, self).__init__()
         fleet_path = sysconfig.get_paths()["purelib"] + '/fleetx/applications/'
@@ -195,7 +195,7 @@ class Bert_large(ModelBase):
             in_tokens=in_tokens)
 
 
-class Bert_base(ModelBase):
+class BertBase(ModelBase):
     def __init__(self):
         super(Bert_base, self).__init__()
         fleet_path = sysconfig.get_paths()["purelib"] + '/fleetx/applications/'
@@ -240,7 +240,7 @@ class MultiSlotCTR(ModelBase):
         self.checkpoints = checkpoints
         self.target = target
 
-    def load_multislot_from_file(self,
+    def load_criteo_from_file(self,
                                  train_files_path,
                                  sparse_feature_dim=1000001,
                                  batch_size=1000,
